Documentation
¶
Index ¶
- Constants
- Variables
- type Option
- func SetDialTimeout(dialTimeout time.Duration) Option
- func SetKeepAlive(keepAlive time.Duration) Option
- func SetProtocolConn(protocol string) Option
- func SetReadTimeout(readTimeout time.Duration) Option
- func SetSkipVerify(skipVerify bool) Option
- func SetTLS(useTLS bool) Option
- func SetTLSConfig(config *tls.Config) Option
- func SetWriteTimeout(writeTimeout time.Duration) Option
- type Stash
Constants ¶
const (
// BrokenPipeError const type to check whether the write process to tcp is broken
BrokenPipeError = "broken pipe"
)
Variables ¶
var CRLF = []byte{13, 10}
CRLF (Carriage Return and Line Feed in ASCII code)
Functions ¶
This section is empty.
Types ¶
type Option ¶
type Option func(*options)
Option function
func SetDialTimeout ¶ added in v1.0.5
SetDialTimeout Option func
func SetProtocolConn ¶ added in v1.0.5
SetProtocolConn Option func set protocol connection between logstash : `tcp` or `udp`
func SetReadTimeout ¶
SetReadTimeout Option func
func SetWriteTimeout ¶
SetWriteTimeout Option func
Click to show internal directories.
Click to hide internal directories.